'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _keyboard = require('./keyboard');

var _keyboard2 = _interopRequireDefault(_keyboard);

var _numberWithCommas = require('../utils/numberWithCommas');

var _numberWithCommas2 = _interopRequireDefault(_numberWithCommas);

var _exists = require('../utils/exists');

var _exists2 = _interopRequireDefault(_exists);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var convertNextValue = function convertNextValue(value, props) {
  var nextValue = String(value).replace(/,/g, '');
  nextValue = nextValue.indexOf('0') !== -1 ? nextValue : nextValue || '';
  nextValue = convertNegativeValues(nextValue, props);
  nextValue = props.commas ? (0, _numberWithCommas2.default)(nextValue) : nextValue;
  return nextValue;
};

var convertNegativeValues = function convertNegativeValues(nextValue, props) {
  var currentValue = nextValue;

  if (nextValue !== '-') {
    currentValue = props.type === 'number' && nextValue !== '' ? parseInt(nextValue, 10) : nextValue;
  }

  return nextValue;
};

var InputKeyboard = function (_React$Component) {
  _inherits(InputKeyboard, _React$Component);

  function InputKeyboard(props) {
    _classCallCheck(this, InputKeyboard);

    var _this = _possibleConstructorReturn(this, (InputKeyboard.__proto__ || Object.getPrototypeOf(InputKeyboard)).call(this, props));

    _this.handleChange = function (e) {
      if (_this.props.currency || _this.props.type === 'number') {
        if (/^[0-9.,]+$/.test(e.target.value)) {
          _this.setNextValue(e.target.value);
        } else {
          _this.setNextValue('');
        }
      } else {
        _this.setNextValue(e.target.value);
      }
    };

    _this.pressKey = function (key) {
      var value = String(_this.state.value).replace(/,/g, '');
      var maxLength = _this.props.maxLength;

      if (maxLength && value.length >= maxLength) {
        return;
      } else {
        if (!value || value === 'NaN') {
          value = '' + key;
        } else if (key === '-') {
          if (value.indexOf(key) >= 0) {
            value = value.substring(1, value.length);
          } else {
            value = '' + key + value;
          }
        } else {
          value = '' + value + key;
        }
      }

      _this.setNextValue(value);
    };

    _this.deleteKey = function () {
      var value = String(_this.state.value).replace(/,/g, '');
      if (value && value.length > 0) {
        var nextValue = value.substring(0, value.toString().length - 1) || '';
        _this.setNextValue(nextValue);
      }
    };

    _this.state = {
      value: convertNextValue((0, _exists2.default)(props.value) ? props.value : '', props)
    };
    return _this;
  }

  _createClass(InputKeyboard, [{
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      if (this.state.value !== nextProps.value) {
        this.setState({
          value: convertNextValue((0, _exists2.default)(nextProps.value) ? nextProps.value : '', nextProps)
        });
      }
    }
  }, {
    key: 'setNextValue',
    value: function setNextValue(value) {
      var nextValue = convertNextValue(value, this.props);
      if (this.props.onChange) {
        this.props.onChange(value);
      }
      this.setState({ value: nextValue });
      if (this.props.setValue) {
        this.props.setValue(nextValue);
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          min = _props.min,
          currency = _props.currency,
          _props$currencyType = _props.currencyType,
          currencyType = _props$currencyType === undefined ? 'dollar' : _props$currencyType,
          commas = _props.commas,
          width = _props.width,
          _onBlur = _props.onBlur,
          type = _props.type,
          autoFocus = _props.autoFocus,
          maxLength = _props.maxLength,
          negatives = _props.negatives,
          showNumpadKeyboard = _props.showNumpadKeyboard,
          name = _props.name,
          innerRef = _props.innerRef;

      var inputClass = (0, _classnames2.default)('input-keyboard__input', { 'input-keyboard__input--currency': currency }, { 'input-keyboard__input--nan': commas || type !== 'number' }, { 'input-keyboard__input--negative': this.state.value.indexOf('-') === 0 });
      return _react2.default.createElement(
        'div',
        { className: 'input-keyboard', style: { width: width } },
        currency && _react2.default.createElement('span', { className: 'input-keyboard__currency input-keyboard__currency--' + currencyType + '-icon' }),
        _react2.default.createElement('input', {
          ref: innerRef || 'input',
          name: name,
          type: commas || showNumpadKeyboard ? 'text' : type,
          className: inputClass,
          pattern: commas || type !== 'number' || showNumpadKeyboard ? '[0-9,-]*' : '[0-9]*',
          inputMode: showNumpadKeyboard ? 'decimal' : 'numeric',
          lang: 'en',
          min: negatives ? Number.MIN_SAFE_INTEGER : min || 0,
          onBlur: function onBlur(e) {
            return _onBlur ? _onBlur(e) : null;
          },
          onChange: this.handleChange,
          value: this.state.value,
          autoFocus: autoFocus,
          maxLength: maxLength
        }),
        _react2.default.createElement(_keyboard2.default, {
          pressKey: this.pressKey,
          deleteKey: this.deleteKey,
          dashKeyActive: this.props.negatives
        })
      );
    }
  }]);

  return InputKeyboard;
}(_react2.default.Component);

InputKeyboard.propTypes = {
  value: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  type: _propTypes2.default.string,
  innerRef: _propTypes2.default.func,
  min: _propTypes2.default.number,
  name: _propTypes2.default.string,
  currency: _propTypes2.default.bool,
  currencyType: _propTypes2.default.string,
  commas: _propTypes2.default.bool,
  autoFocus: _propTypes2.default.bool,
  onBlur: _propTypes2.default.func,
  setValue: _propTypes2.default.func,
  maxLength: _propTypes2.default.number,
  width: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  negativeEnabled: _propTypes2.default.bool,
  showNumpadKeyboard: _propTypes2.default.bool,
  onChange: _propTypes2.default.func
};

InputKeyboard.defaultProps = {
  type: 'number'
};

exports.default = InputKeyboard;