'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactHighlightWords = require('react-highlight-words');

var _reactHighlightWords2 = _interopRequireDefault(_reactHighlightWords);

var _deviceDetector = require('../utils/deviceDetector');

var _stringHelper = require('../utils/string-helper');

var _stringHelper2 = _interopRequireDefault(_stringHelper);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function OnlyClickListOption(props) {
  var id = props.id,
      value = props.value,
      label = props.label,
      addition = props.addition,
      checked = props.checked,
      tooltipKey = props.tooltipKey,
      typedValue = props.typedValue,
      highlight = props.highlight,
      highlightSanitizer = props.highlightSanitizer,
      listType = props.listType,
      _onClick = props.onClick,
      onHelpClick = props.onHelpClick,
      itemClasses = props.itemClasses,
      disabled = props.disabled,
      optionComponent = props.optionComponent,
      _props$animatedSelect = props.animatedSelection,
      animatedSelection = _props$animatedSelect === undefined ? true : _props$animatedSelect,
      _props$withArrow = props.withArrow,
      withArrow = _props$withArrow === undefined ? true : _props$withArrow,
      scrollable = props.scrollable,
      dataTest = props.dataTest;

  var optionClass = (0, _classnames2.default)(itemClasses, 'oc-options-list__item oc-list-option', { 'oc-list-option--animate-selection': animatedSelection }, { 'oc-list-option--checked': checked }, { 'oc-list-option--no-touch': !(0, _deviceDetector.isIOS)() }, { 'oc-list-option--with-addition': addition }, { 'oc-list-option--disabled': disabled }, { 'oc-options-list__item--scrollable': scrollable });

  var messageClass = (0, _classnames2.default)('oc-option__message');
  var multiSelectIconClass = (0, _classnames2.default)('oc-option__checked-icon', { 'oc-option__checked-icon--checked': checked });
  var tooltipIconClass = (0, _classnames2.default)('oc-option__help-icon', { 'oc-option__help-icon--checked': checked });
  var hasNextIcon = listType !== 'multiSelect' && withArrow;

  return _react2.default.createElement(
    'li',
    { id: id, className: optionClass, onClick: function onClick() {
        return !disabled && _onClick(value);
      }, disabled: disabled, 'data-test': dataTest },
    optionComponent ? _react2.default.createElement(
      'span',
      null,
      optionComponent(props)
    ) : _react2.default.createElement(
      'span',
      { className: 'oc-list-option__container' },
      listType === 'multiSelect' && _react2.default.createElement('span', { className: multiSelectIconClass }),
      _react2.default.createElement(
        'span',
        { className: messageClass },
        highlight ? _react2.default.createElement(_reactHighlightWords2.default, {
          highlightClassName: 'oc-option__search-term',
          searchWords: (0, _stringHelper2.default)(typedValue.trim()).split(' '),
          textToHighlight: label,
          sanitize: highlightSanitizer
        }) : label,
        addition && _react2.default.createElement(
          'div',
          { className: 'oc-option__addition' },
          addition
        )
      ),
      tooltipKey && _react2.default.createElement('span', { className: tooltipIconClass, id: tooltipKey, onClick: onHelpClick && onHelpClick.bind(null, tooltipKey), tabIndex: '-1' }),
      hasNextIcon && _react2.default.createElement('span', { className: 'oc-option__next-icon' })
    )
  );
}

OnlyClickListOption.propTypes = {
  value: _propTypes2.default.string.isRequired,
  label: _propTypes2.default.string.isRequired,
  id: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  addition: _propTypes2.default.string,
  tooltipKey: _propTypes2.default.oneOfType([_propTypes2.default.string, _propTypes2.default.number]),
  typedValue: _propTypes2.default.string,
  checked: _propTypes2.default.bool,
  disabled: _propTypes2.default.bool,
  highlight: _propTypes2.default.bool,
  animatedSelection: _propTypes2.default.bool,
  highlightSanitizer: _propTypes2.default.func,
  listType: _propTypes2.default.string,
  itemClasses: _propTypes2.default.string,
  onClick: _propTypes2.default.func,
  onHelpClick: _propTypes2.default.func,
  optionComponent: _propTypes2.default.func,
  withArrow: _propTypes2.default.bool,
  scrollable: _propTypes2.default.bool,
  dataTest: _propTypes2.default.string
};

exports.default = OnlyClickListOption;